@@ -5,7 +5,7 @@ from urllib.parse import urljoin
 
 from pyvultr.utils import BaseDataclass, VultrPagination, get_only_value
 
-from .base import BaseVultrV2
+from .base import BaseVultrV2, command
 
 
 @dataclass
@@ -24,8 +24,7 @@ class Invoice(BaseDataclass):
     date: str  # Date the invoice was generated.
     description: str  # Description of the invoice.
     amount: float  # Amount of the invoice in dollars.
-    # TODO check with API(Docs not match with code)
-    balance: float = None  # The accounts balance in dollars.
+    balance: float  # The accounts balance in dollars.
 
 
 @dataclass
@@ -43,7 +42,7 @@ class InvoiceItem(BaseDataclass):
 class BillingAPI(BaseVultrV2):
     """Vultr Billing API.
 
-    Reference: https://www.vultr.com/zh/api/#tag/billing
+    Reference: https://www.vultr.com/api/#tag/billing
 
     Read-only billing information for your user account.
 
@@ -59,6 +58,7 @@ class BillingAPI(BaseVultrV2):
         """Get base url for all API in this section."""
         return urljoin(super().base_url, "billing")
 
+    @command
     def list_bills(self, per_page: int = None, cursor: str = None, capacity: int = None) -> VultrPagination[Bill]:
         """Retrieve list of billing history.
 
@@ -79,6 +79,7 @@ class BillingAPI(BaseVultrV2):
             capacity=capacity,
         )
 
+    @command
     def list_invoices(self, per_page: int = None, cursor: str = None, capacity: int = None) -> VultrPagination[Invoice]:
         """Retrieve full specified invoice.
 
@@ -99,6 +100,7 @@ class BillingAPI(BaseVultrV2):
             capacity=capacity,
         )
 
+    @command
     def get_invoice(self, invoice_id: str) -> Invoice:
         """Retrieve specified invoice.
 
@@ -111,6 +113,7 @@ class BillingAPI(BaseVultrV2):
         resp = self._get(f"/invoices/{invoice_id}")
         return Invoice.from_dict(get_only_value(resp))
 
+    @command
     def list_invoice_items(
         self,
         invoice_id: str,
